@@ -27,27 +27,25 @@
 ##' used to project the species distribution model(s)
 ##' @param models.chosen a \code{vector} containing model names to be kept, must be either 
 ##' \code{all} or a sub-selection of model names that can be obtained with the 
-##' \code{\link{get_built_models}} function
+##' \code{\link{get_built_models}} function applied to \code{bm.mod}
 ##' 
 ##' @param metric.binary (\emph{optional, default} \code{NULL}) \cr 
 ##' A \code{vector} containing evaluation metric names to be used to transform prediction values 
 ##' into binary values based on models evaluation scores obtained with the 
 ##' \code{\link{BIOMOD_Modeling}} function. Must be among \code{all} (same evaluation metrics than 
 ##' those of \code{bm.mod}) or \code{POD}, \code{FAR}, \code{POFD}, \code{SR}, \code{ACCURACY}, 
-##' \code{BIAS}, \code{ROC}, \code{TSS}, \code{KAPPA}, \code{OR}, \code{ORSS}, \code{CSI}, 
+##' \code{BIAS}, \code{AUCroc}, \code{AUCprg}, \code{TSS}, \code{KAPPA}, \code{OR}, \code{ORSS}, \code{CSI}, 
 ##' \code{ETS}, \code{BOYCE}, \code{MPA}
+##' \cr \emph{Note that this is for binary data only.}
 ##' @param metric.filter (\emph{optional, default} \code{NULL}) \cr 
 ##' A \code{vector} containing evaluation metric names to be used to transform prediction values 
 ##' into filtered values based on models evaluation scores obtained with the 
 ##' \code{\link{BIOMOD_Modeling}} function. Must be among \code{all} (same evaluation metrics than 
 ##' those of \code{bm.mod}) or \code{POD}, \code{FAR}, \code{POFD}, \code{SR}, \code{ACCURACY}, 
-##' \code{BIAS}, \code{ROC}, \code{TSS}, \code{KAPPA}, \code{OR}, \code{ORSS}, \code{CSI}, 
+##' \code{BIAS}, \code{AUCroc}, \code{AUCprg}, \code{TSS}, \code{KAPPA}, \code{OR}, \code{ORSS}, \code{CSI}, 
 ##' \code{ETS}, \code{BOYCE}, \code{MPA}
+##' \cr \emph{Note that this is for binary data only.}
 ##' 
-##' @param compress (\emph{optional, default} \code{TRUE}) \cr 
-##' A \code{logical} or a \code{character} value defining whether and how objects should be 
-##' compressed when saved on hard drive. Must be either \code{TRUE}, \code{FALSE}, \code{xz} or 
-##' \code{gzip} (see Details)
 ##' @param build.clamping.mask (\emph{optional, default} \code{TRUE}) \cr 
 ##' A \code{logical} value defining whether a clamping mask should be built and saved on hard 
 ##' drive or not (see Details)
@@ -88,23 +86,44 @@
 ##' calibration / validation range, identifying locations where predictions are uncertain. \cr \cr
 ##' 
 ##' \code{...} can take the following values :
-##' \itemize{
+##' \describe{
 ##   \item \code{clamping.level} : a \code{logical} value defining whether \code{clamping.mask} 
 ##   cells with at least one variable out of its calibration range are to be removed from the 
 ##   projections or not
-##'   \item \code{omit.na} : a \code{logical} value defining whether all not fully referenced 
-##'   environmental points will get \code{NA} as predictions or not
-##'   \item \code{on_0_1000} : a \code{logical} value defining whether \code{0 - 1} probabilities 
-##'   are to be converted to \code{0 - 1000} scale to save memory on backup
-##'   \item \code{do.stack} : a \code{logical} value defining whether all projections are to be 
-##'   saved as one \code{\link[terra:rast]{SpatRaster}} object or several 
-##'   \code{\link[terra:rast]{SpatRaster}} files (\emph{the default if projections are too heavy to 
-##'   be all loaded at once in memory})
-##'   \item \code{keep.in.memory} : a \code{logical} value defining whether all projections are 
-##'   to be kept loaded at once in memory, or only links pointing to hard drive are to be returned
-##'   \item \code{output.format} : a \code{character} value corresponding to the projections 
-##'   saving format on hard drive, must be either \code{.grd}, \code{.img}, \code{.tif} or \code{.RData} (the 
-##'   default if \code{new.env} is given as \code{matrix} or \code{data.frame})
+##'   \item{omit.na}{(\emph{optional, default} \code{TRUE}) : \cr
+##'   a \code{logical} value defining whether all not fully referenced environmental points will 
+##'   get \code{NA} as predictions or not
+##'   }
+##'   \item{digits}{(\emph{optional, default} \code{0}) : \cr
+##'   an \code{integer} value corresponding to the number of digits of the predictions
+##'   }
+##'   \item{on_0_1000}{(\emph{optional, default} \code{TRUE}) : \cr
+##'   a \code{logical} value defining whether \code{0 - 1} probabilities are to be converted to 
+##'   \code{0 - 1000} scale to save memory on backup
+##'   }
+##'   \item{keep.in.memory}{(\emph{optional, default} \code{TRUE}) : \cr
+##'   a \code{logical} value defining whether all projections are to be kept loaded at once in 
+##'   memory, or only links pointing to hard drive are to be returned
+##'   }
+##'   \item{do.stack}{(\emph{optional, default} \code{TRUE}) : \cr 
+##'   a \code{logical} value defining whether all projections are to be saved as one 
+##'   \code{\link[terra:rast]{SpatRaster}} object or several \code{\link[terra:rast]{SpatRaster}} 
+##'   files (\emph{the default if projections are too heavy to be all loaded at once in memory})
+##'   }
+##'   \item{output.format}{(\emph{optional, default} \code{.RData} or \code{.tif}) : \cr
+##'   a \code{character} value corresponding to the projections saving format on hard drive, must 
+##'   be either \code{.grd}, \code{.img}, \code{.tif} or \code{.RData} (the default if 
+##'   \code{new.env} is given as \code{matrix} or \code{data.frame})
+##'   }
+##'   \item{compress}{(\emph{optional, default} \code{TRUE}) : \cr
+##'   a \code{logical} or a \code{character} value defining whether and how objects should be 
+##'   compressed when saved on hard drive. Must be either \code{TRUE}, \code{FALSE}, \code{gzip} 
+##'   (for Windows OS) or \code{xz} (for other OS)
+##'   }
+##'   \item{overwrite}{(\emph{optional, default} \code{do.stack}) : \cr
+##'   a \code{logical} defining whether pre-existing projections with same modeling ID and 
+##'   project name should be replaced or not
+##'   }
 ##' }
 ##' 
 ##' 
@@ -148,10 +167,10 @@
 ##' } else {
 ##' 
 ##'   # Format Data with true absences
-##'   myBiomodData <- BIOMOD_FormatingData(resp.var = myResp,
-##'                                        expl.var = myExpl,
+##'   myBiomodData <- BIOMOD_FormatingData(resp.name = myRespName,
+##'                                        resp.var = myResp,
 ##'                                        resp.xy = myRespXY,
-##'                                        resp.name = myRespName)
+##'                                        expl.var = myExpl)
 ##' 
 ##'   # Model single models
 ##'   myBiomodModelOut <- BIOMOD_Modeling(bm.format = myBiomodData,
@@ -161,7 +180,7 @@
 ##'                                       CV.nb.rep = 2,
 ##'                                       CV.perc = 0.8,
 ##'                                       OPT.strategy = 'bigboss',
-##'                                       metric.eval = c('TSS','ROC'),
+##'                                       metric.eval = c('TSS','AUCroc'),
 ##'                                       var.import = 3,
 ##'                                       seed.val = 42)
 ##' }
@@ -193,6 +212,7 @@
 ##' 
 ###################################################################################################
 
+
 BIOMOD_Projection <- function(bm.mod,
                               proj.name,
                               new.env,
@@ -200,16 +220,16 @@ BIOMOD_Projection <- function(bm.mod,
                               models.chosen = 'all',
                               metric.binary = NULL,
                               metric.filter = NULL,
-                              compress = TRUE,
                               build.clamping.mask = TRUE,
                               nb.cpu = 1,
                               seed.val = NULL,
-                              ...) {
+                              ...)
+{
   .bm_cat("Do Single Models Projection")
   
   ## 0. Check arguments ---------------------------------------------------------------------------
   args <- .BIOMOD_Projection.check.args(bm.mod, proj.name, new.env, new.env.xy
-                                        , models.chosen, metric.binary, metric.filter, compress, seed.val, ...)
+                                        , models.chosen, metric.binary, metric.filter, seed.val, ...)
   for (argi in names(args)) { assign(x = argi, value = args[[argi]]) }
   rm(args)
   
@@ -218,7 +238,6 @@ BIOMOD_Projection <- function(bm.mod,
   #   rm(list=ls(name=env), pos=env)
   # }
   
-  
   ## 1. Create output object ----------------------------------------------------------------------
   proj_out <- new('BIOMOD.projection.out',
                   proj.name = proj.name,
@@ -228,8 +247,10 @@ BIOMOD_Projection <- function(bm.mod,
                   models.projected = models.chosen,
                   scale.models = bm.mod@scale.models,
                   coord = new.env.xy,
+                  data.type = bm.mod@data.type,
                   modeling.id = bm.mod@modeling.id)
   proj_out@models.out@link = bm.mod@link
+  proj_out@call <- match.call()
   
   proj_is_raster <- FALSE
   if (inherits(new.env, 'SpatRaster')) {
@@ -279,9 +300,7 @@ BIOMOD_Projection <- function(bm.mod,
     }
   }
   
-  
   ## 4. MAKING PROJECTIONS ------------------------------------------------------------------------
-  
   if (nb.cpu > 1) {
     if (.getOS() != "windows") {
       if (!isNamespaceLoaded("doParallel")) { 
@@ -296,42 +315,79 @@ BIOMOD_Projection <- function(bm.mod,
     new.env.wrap <- wrap(new.env) # ensure parallel run compatibility
   }
   
-  proj <- foreach(mod.name = models.chosen) %dopar% {
-    cat("\n\t> Projecting", mod.name, "...")
-    if (proj_is_raster) {
-      new.env <- unwrap(new.env.wrap) # ensure parallel run compatibility
-      names(new.env) <- bm.mod@expl.var.names
-    }
-    if (do.stack) {
-      filename <- NULL
-    } else {
-      filename <- file.path(namePath, "individual_projections",
-                            paste0(nameProj, "_", mod.name, 
-                                   ifelse(output.format == ".RData"
-                                          , ".tif", output.format)))
-    }
-    mod <- get(BIOMOD_LoadModels(bm.out = bm.mod, full.name = mod.name))
-    temp_workdir = NULL
-    if (length(grep("MAXENT$", mod.name)) == 1) {
-      temp_workdir = mod@model_output_dir
-    }
-    pred.tmp <- predict(mod, new.env, on_0_1000 = on_0_1000, 
-                        filename = filename, omit.na = omit.na, 
-                        temp_workdir = temp_workdir, seedval = seed.val, 
-                        overwrite = TRUE, mod.name = mod.name)
-    if (do.stack) {
+  proj <- foreach(mod.name = models.chosen) %dopar%
+    {
+      cat("\n\t> Projecting", mod.name, "...")
       if (proj_is_raster) {
-        return(wrap(pred.tmp)) 
+        new.env <- unwrap(new.env.wrap) # ensure parallel run compatibility
+        names(new.env) <- bm.mod@expl.var.names
+      }
+      if (do.stack) {
+        filename <- NULL
       } else {
-        return(pred.tmp)
+        filename <- file.path(namePath, "individual_projections",
+                              paste0(nameProj, "_", mod.name, 
+                                     ifelse(output.format == ".RData"
+                                            , ".tif", output.format)))
+      }
+      mod <- get(BIOMOD_LoadModels(bm.out = bm.mod, full.name = mod.name))
+      temp_workdir = NULL
+      if (length(grep("MAXENT$", mod.name)) == 1) {
+        temp_workdir = mod@model_output_dir
+      }
+      
+      pred.tmp <- predict(mod, new.env, on_0_1000 = on_0_1000, 
+                          filename = filename, omit.na = omit.na, 
+                          temp_workdir = temp_workdir, seedval = seed.val, 
+                          overwrite = overwrite, mod.name = mod.name)
+
+      
+      ## Cleaning 
+      if (bm.mod@data.type %in% c("count", "abundance")) {
+        pred.tmp[pred.tmp < 0] <- 0
+        pred.tmp <- round(pred.tmp,digits = digits)
+        
+      } else if (bm.mod@data.type %in% c("ordinal", "multiclass")) {
+        data_sp <- get_formal_data(bm.mod, subinfo = "resp.var")
+        #nblevels <- length(levels(data_sp))
+        if (length(grep("GAM$|GLM$|XGBOOST$", mod.name)) == 1) {
+          # pred.tmp[pred.tmp < 1] <- 1
+          # pred.tmp[pred.tmp > nblevels] <- nblevels
+          # pred.tmp <- round(as.numeric(pred.tmp))
+          # if (inherits(pred.tmp, "SpatRaster")){
+          #   pred.tmp <- terra::subst(pred.tmp, 1:length(levels(data_sp)), levels(data_sp))
+          # } else {
+          #   pred.tmp <- factor(pred.tmp, labels = levels(data_sp))
+          # }
+          pred.tmp <- .numeric2factor(pred.tmp, data_sp, ordered = (bm.mod@data.type == "ordinal"))
+        } else if ((length(grep("MARS$", mod.name)) == 1)){
+          if (!inherits(pred.tmp, "SpatRaster")){
+            pred.tmp <- factor(pred.tmp, levels = levels(data_sp))
+          } else {
+            pred.tmp <- terra::subst(pred.tmp, 1:length(levels(data_sp)), levels(data_sp))
+          }
+        } else {
+          if (!inherits(pred.tmp, "SpatRaster")){
+            pred.tmp <- factor(pred.tmp, levels = 1:length(levels(data_sp)), labels = levels(data_sp),
+                               ordered = ifelse(bm.mod@data.type == "ordinal", TRUE, FALSE))
+          }
+        }
+      }
+      
+      
+      if (do.stack) {
+        if (proj_is_raster) {
+          return(wrap(pred.tmp)) 
+        } else {
+          return(pred.tmp)
+        }
+      } else {
+        cat("\n\t\t", filename)
+        return(filename)
       }
-    } else {
-      cat(filename)
-      return(filename)
     }
-  }
   
-  ## Putting predictions into the right format
+  ## putting predictions into the right format
   if (do.stack) {
     if (proj_is_raster) {
       proj <- rast(lapply(proj, unwrap)) # SpatRaster needs to be wrapped before saving
@@ -344,7 +400,6 @@ BIOMOD_Projection <- function(bm.mod,
       proj.trans <- proj
       proj <- .format_proj.df(proj, obj.type = "mod")
     }
-    
     if (keep.in.memory) {
       proj_out@proj.out@val <- proj
       proj_out@proj.out@inMemory <- TRUE
@@ -353,34 +408,39 @@ BIOMOD_Projection <- function(bm.mod,
   
   ## save projections
   proj_out@type <- .get_env_class(new.env)
-  if (!do.stack){
+  if (!do.stack) {
     saved.files = unlist(proj)
   } else {
     assign(x = nameProjSp, value = proj)
     saved.files <- file.path(namePath, paste0(nameProjSp, output.format))
     if (output.format == '.RData') {
       save(list = nameProjSp, file = saved.files, compress = compress)
-    } else  {
-      writeRaster(x = rast(get(nameProjSp)), filename = saved.files,
-                  overwrite = TRUE, datatype = ifelse(on_0_1000, "INT2S", "FLT4S"), NAflag = -9999)
+    } else {
+      save.type <- ifelse(bm.mod@data.type == "binary"
+                          , ifelse(on_0_1000, "INT2S", "FLT4S")
+                          , ifelse(digits == 0, "INT2S", "FLT4S"))
+      writeRaster(x = rast(get(nameProjSp)), filename = saved.files
+                  , overwrite = TRUE, datatype = save.type
+                  , NAflag = -9999)
     }
   }
   proj_out@proj.out@link <- saved.files
   
-  # now that proj have been saved, it can be unwrapped if it is a SpatRaster
+  ## now that proj have been saved, it can be unwrapped if it is a SpatRaster
   if (proj_is_raster && do.stack) {
     proj.trans <- rast(proj.trans) 
   }
   
   ## 5. Compute binary and/or filtered transformation ---------------------------------------------
-  if (!is.null(metric.binary) | !is.null(metric.filter)) {
+  if (bm.mod@data.type == "binary" && (!is.null(metric.binary) || !is.null(metric.filter)))
+  {
     cat("\n")
     saved.files.binary <- NULL
     saved.files.filtered <- NULL
     thresholds <- get_evaluations(bm.mod, full.name = models.chosen)
     if (!on_0_1000) { thresholds[, "cutoff"]  <- thresholds[, "cutoff"] / 1000 }
     
-    ## Do binary/filtering transformation
+    ## Do binary/filtering transformation -------------------------------------
     for (eval.meth in unique(c(metric.binary, metric.filter))) {
       thres.tmp <- thresholds[which(thresholds$metric.eval == eval.meth), ]
       rownames(thres.tmp) <- thres.tmp$full.name
@@ -388,6 +448,7 @@ BIOMOD_Projection <- function(bm.mod,
       
       cat("\n\t> Building", eval.meth, "binaries / filtered")
       if (!do.stack) {
+        ## NO stack + binary + filtering transformation -----------------------
         for (i in 1:length(proj_out@proj.out@link)) {
           file.tmp <- proj_out@proj.out@link[i]
           output.format.search <- paste0("\\",output.format)
@@ -408,8 +469,7 @@ BIOMOD_Projection <- function(bm.mod,
                                      paste0("_", eval.meth, "filt", output.format),
                                      file.tmp)
             saved.files.filtered <- c(saved.files.filtered, file.tmp.filtered)
-            writeRaster(x = bm_BinaryTransformation(rast(file.tmp), thres.tmp[i],
-                                                    do.filtering = TRUE),
+            writeRaster(x = bm_BinaryTransformation(rast(file.tmp), thres.tmp[i], do.filtering = TRUE),
                         filename = file.tmp.filtered,
                         overwrite = TRUE,
                         datatype = ifelse(on_0_1000, "INT2S", "FLT4S"),
@@ -417,6 +477,7 @@ BIOMOD_Projection <- function(bm.mod,
           }
         }
       } else {
+        ## Stack + binary transformation --------------------------------------
         if (eval.meth %in% metric.binary) {
           nameBin <- paste0(nameProjSp, "_", eval.meth, "bin")
           assign(x = nameBin, value = bm_BinaryTransformation(proj.trans, thres.tmp))
@@ -442,7 +503,7 @@ BIOMOD_Projection <- function(bm.mod,
           }
         }
         
-        
+        ## Stack + filtering transformation -----------------------------------
         if (eval.meth %in% metric.filter) {
           nameFilt <- paste0(nameProjSp, "_", eval.meth, "filt")
           assign(x = nameFilt,
@@ -471,7 +532,7 @@ BIOMOD_Projection <- function(bm.mod,
       }
     }
     
-    ### save binary/filtered file link into proj_out ----------------------------
+    ## Save binary/filtered files link into proj_out --------------------------
     if (!is.null(metric.binary)) {
       proj_out@proj.out@link <- c(proj_out@proj.out@link, saved.files.binary)
     }
@@ -482,7 +543,6 @@ BIOMOD_Projection <- function(bm.mod,
   }
   
   ## 6. SAVE MODEL OBJECT ON HARD DRIVE -----------------------------------------------------------
-  ## save a copy of output object without value to be lighter
   nameOut <- paste0(bm.mod@sp.name, ".", proj.name, ".projection.out")
   if (!keep.in.memory) { proj_out <- free(proj_out) }
   assign(nameOut, proj_out)
@@ -492,10 +552,11 @@ BIOMOD_Projection <- function(bm.mod,
   return(proj_out)
 }
 
-# .BIOMOD_Projection.check.args---------------------------------------------
+
+###################################################################################################
 
 .BIOMOD_Projection.check.args <- function(bm.mod, proj.name, new.env, new.env.xy,
-                                          models.chosen, metric.binary, metric.filter, compress, seed.val, ...)
+                                          models.chosen, metric.binary, metric.filter, seed.val, ...)
 {
   args <- list(...)
   
@@ -550,7 +611,7 @@ BIOMOD_Projection <- function(bm.mod,
   }
   
   ## 4. Check new.env.xy ------------------------------------------------------
-  if (!is.null(new.env.xy)  & !inherits(new.env, 'SpatRaster')) {
+  if (!is.null(new.env.xy) & !inherits(new.env, 'SpatRaster')) {
     new.env.xy = as.data.frame(new.env.xy)
     if (ncol(new.env.xy) != 2 || nrow(new.env.xy) != nrow(new.env)) {
       stop("invalid xy coordinates argument given -- dimensions mismatch !")
@@ -558,6 +619,7 @@ BIOMOD_Projection <- function(bm.mod,
   } else {
     new.env.xy = data.frame()
   }
+  
   ## 5. Check models.chosen ---------------------------------------------------
   if (models.chosen[1] == 'all') {
     models.chosen <- bm.mod@models.computed
@@ -586,35 +648,42 @@ BIOMOD_Projection <- function(bm.mod,
   
   ## 6. Check metric.binary & metric.filter -----------------------------------
   if (!is.null(metric.binary) | !is.null(metric.filter)) {
-    models.evaluation <- get_evaluations(bm.mod)
-    if (is.null(models.evaluation)) {
-      warning("Binary and/or Filtered transformations of projection not ran because of models evaluation information missing")
+    if ( bm.mod@data.type != "binary"){
+      cat ("No metric.binary or metric.filter are needed with",bm.mod@data.type, "data")
+      metric.binary <- NULL
+      metric.filter <- NULL
     } else {
-      available.evaluation <- unique(models.evaluation$metric.eval)
-      if (!is.null(metric.binary) && metric.binary[1] == 'all') {
-        metric.binary <- available.evaluation
-      } else if (!is.null(metric.binary) && sum(!(metric.binary %in% available.evaluation)) > 0) {
-        warning(paste0(toString(metric.binary[!(metric.binary %in% available.evaluation)]),
-                       " Binary Transformation were switched off because no corresponding evaluation method found"))
-        metric.binary <- metric.binary[metric.binary %in% available.evaluation]
-      }
-      
-      if (!is.null(metric.filter) && metric.filter[1] == 'all') {
-        metric.filter <- available.evaluation
-      } else if (!is.null(metric.filter) && sum(!(metric.filter %in% available.evaluation)) > 0) {
-        warning(paste0(toString(metric.filter[!(metric.filter %in% available.evaluation)]),
-                       " Filtered Transformation were switched off because no corresponding evaluation method found"))
-        metric.filter <- metric.filter[metric.filter %in% available.evaluation]
+      models.evaluation <- get_evaluations(bm.mod)
+      if (is.null(models.evaluation)) {
+        warning("Binary and/or Filtered transformations of projection not ran because of models evaluation information missing")
+      } else {
+        available.evaluation <- unique(models.evaluation$metric.eval)
+        if (!is.null(metric.binary) && metric.binary[1] == 'all') {
+          metric.binary <- available.evaluation
+        } else if (!is.null(metric.binary) && sum(!(metric.binary %in% available.evaluation)) > 0) {
+          warning(paste0(toString(metric.binary[!(metric.binary %in% available.evaluation)]),
+                         " Binary Transformation were switched off because no corresponding evaluation method found"))
+          metric.binary <- metric.binary[metric.binary %in% available.evaluation]
+        }
+        
+        if (!is.null(metric.filter) && metric.filter[1] == 'all') {
+          metric.filter <- available.evaluation
+        } else if (!is.null(metric.filter) && sum(!(metric.filter %in% available.evaluation)) > 0) {
+          warning(paste0(toString(metric.filter[!(metric.filter %in% available.evaluation)]),
+                         " Filtered Transformation were switched off because no corresponding evaluation method found"))
+          metric.filter <- metric.filter[metric.filter %in% available.evaluation]
+        }
       }
     }
   }
   
   ## 7. Check compress --------------------------------------------------------
+  compress <- ifelse(is.null(args$compress), TRUE, args$compress)
   if (compress == 'xz') {
     compress <- ifelse(.Platform$OS.type == 'windows', 'gzip', 'xz')
   }
   
-  ## 9. Check output.format ---------------------------------------------------
+  ## 8. Check output.format ---------------------------------------------------
   output.format <- args$output.format # raster output format
   if (!is.null(output.format)) {
     if (!output.format %in% c(".img", ".grd", ".tif", ".RData")) {
@@ -653,12 +722,21 @@ BIOMOD_Projection <- function(bm.mod,
     # if (test[1] > test[2]) {
     #   terraOptions(todisk = TRUE) 
     # }
-  } else if (output.format == "RData"){
+  } else if (output.format == "RData") {
     cat("\n\t\t! 'do.stack' arg is always set as TRUE for .RData output format") 
     do.stack <- TRUE
   }
   
+  ## 10. Check on_0_1000 ------------------------------------------------------
+  on_0_1000 <- ifelse(is.null(args$on_0_1000), TRUE, args$on_0_1000)
+  if (bm.mod@data.type %in% c("count", "abundance", "ordinal", "multiclass")) { on_0_1000 <- FALSE }
   
+  ## 11.Check overwrite -------------------------------------------------------
+  overwrite <- ifelse(is.null(args$overwrite), ifelse(do.stack, TRUE, FALSE), args$overwrite)
+  if (!overwrite){
+    cat("\n\t\t! 'overwrite' arg is set as FALSE. Projections that have already been saved will not be redone. 
+        Please be carfeul if you have changed the models in the meantime. ")
+  }
   
   return(list(proj.name = proj.name,
               new.env = new.env,
@@ -666,22 +744,23 @@ BIOMOD_Projection <- function(bm.mod,
               models.chosen = models.chosen,
               metric.binary = metric.binary,
               metric.filter = metric.filter,
-              compress = compress,
+              seed.val = seed.val,
+              omit.na = ifelse(is.null(args$omit.na), TRUE, args$omit.na),
+              digits = ifelse(is.null(args$digits), 0, args$digits),
+              on_0_1000 = on_0_1000,
+              keep.in.memory = ifelse(is.null(args$keep.in.memory), TRUE, args$keep.in.memory),
               do.stack = do.stack,
               output.format = output.format,
-              omit.na = ifelse(is.null(args$omit.na), TRUE, args$omit.na),
-              do.stack = do.stack,
-              keep.in.memory = ifelse(is.null(args$keep.in.memory), TRUE, args$keep.in.memory),
-              on_0_1000 = ifelse(is.null(args$on_0_1000), TRUE, args$on_0_1000),
-              seed.val = seed.val))
+              compress = compress,
+              overwrite = overwrite))
 }
 
 
-### .build_clamping_mask -------------------------------------------------------
+###################################################################################################
 
 .build_clamping_mask <- function(env, MinMax)
 {
-  if (inherits(env, 'SpatRaster')) { 
+  if (inherits(env, 'SpatRaster')) {
     ## raster case ------------------------------------------------------------
     env <- subset(env, names(MinMax))
     ## create an empty mask
@@ -694,20 +773,16 @@ BIOMOD_Projection <- function(bm.mod,
           bm_BinaryTransformation(subset(env, e.v), MinMax[[e.v]]$max) + ## pix with values outside of calib range
           (ref.mask - bm_BinaryTransformation(subset(env, e.v), MinMax[[e.v]]$min)) ## pix with no values (within env[[1]] area)
       } else if (!is.null(MinMax[[e.v]]$levels)) { # factorial variable
-        clamp.mask <- 
-          clamp.mask + 
-          app(subset(env, e.v),
-              function(x) {
-                ifelse(as.character(x) %in% MinMax[[e.v]]$levels,
-                       1,
-                       0)
-              }) ## pix with values outside of calib range
+        clamp.mask <- clamp.mask + 
+          app(subset(env, e.v), function(x) {
+            ifelse(as.character(x) %in% MinMax[[e.v]]$levels, 1, 0)
+          }) ## pix with values outside of calib range
       }
     }
     
-  } else if (is.data.frame(env) | is.matrix(env) | is.numeric(env)) { ## matrix and data.frame case ---------------------------------------------
+  } else if (is.data.frame(env) || is.matrix(env) || is.numeric(env)) {
+    ## matrix and data.frame case ---------------------------------------------
     env <- as.data.frame(env)
-    
     # create an empty mask
     clamp.mask <- rep(0, nrow(env))
     
